@@ -8,7 +8,7 @@
  */
 
 /*
- * Copyright (C) 2006-2015 Oracle Corporation
+ * Copyright (C) 2006-2016 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -49,7 +49,7 @@
 
 /* Includes for the raw disk stuff. */
 #ifdef RT_OS_WINDOWS
-# include <windows.h>
+# include <iprt/win/windows.h>
 # include <winioctl.h>
 #elif defined(RT_OS_LINUX) || defined(RT_OS_DARWIN) \
     || defined(RT_OS_SOLARIS) || defined(RT_OS_FREEBSD)
@@ -452,6 +452,7 @@ static HRESULT SetInt64(ComPtr<IMachine> pMachine, const char *pszKeyBase, const
  */
 static RTEXITCODE CmdLoadSyms(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aSession);
     HRESULT rc;
 
     /*
@@ -467,7 +468,7 @@ static RTEXITCODE CmdLoadSyms(int argc, char **argv, ComPtr<IVirtualBox> aVirtua
     const char *pszFilename;
     int64_t     offDelta = 0;
     const char *pszModule = NULL;
-    uint64_t    ModuleAddress = ~0;
+    uint64_t    ModuleAddress = UINT64_MAX;
     uint64_t    ModuleSize = 0;
 
     /* filename */
@@ -528,6 +529,7 @@ static RTEXITCODE CmdLoadSyms(int argc, char **argv, ComPtr<IVirtualBox> aVirtua
  */
 static RTEXITCODE CmdLoadMap(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aSession);
     HRESULT rc;
 
     /*
@@ -600,6 +602,7 @@ static RTEXITCODE CmdLoadMap(int argc, char **argv, ComPtr<IVirtualBox> aVirtual
 
 static DECLCALLBACK(void) handleVDError(void *pvUser, int rc, RT_SRC_POS_DECL, const char *pszFormat, va_list va)
 {
+    RT_NOREF(pvUser);
     RTMsgErrorV(pszFormat, va);
     RTMsgError("Error code %Rrc at %s(%u) in function %s", rc, RT_SRC_POS_ARGS);
 }
@@ -612,6 +615,7 @@ static DECLCALLBACK(int) handleVDMessage(void *pvUser, const char *pszFormat, va
 
 static RTEXITCODE CmdSetHDUUID(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     Guid uuid;
     RTUUID rtuuid;
     enum eUuidType {
@@ -690,6 +694,8 @@ static RTEXITCODE CmdSetHDUUID(int argc, char **argv, ComPtr<IVirtualBox> aVirtu
 
 static RTEXITCODE CmdDumpHDInfo(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
+
     /* we need exactly one parameter: the image file */
     if (argc != 1)
     {
@@ -768,6 +774,7 @@ static int partRead(RTFILE File, PHOSTPARTITIONS pPart)
 
             /** @todo r=bird: C have this handy concept called structures which
              *        greatly simplify data access...  (Someone is really lazy here!) */
+#if 0 /* unused */
             uint64_t firstUsableLBA     = RT_MAKE_U64_FROM_U8(partitionTableHeader[40],
                                                               partitionTableHeader[41],
                                                               partitionTableHeader[42],
@@ -777,6 +784,7 @@ static int partRead(RTFILE File, PHOSTPARTITIONS pPart)
                                                               partitionTableHeader[46],
                                                               partitionTableHeader[47]
                                                               );
+#endif
             lastUsableLBA               = RT_MAKE_U64_FROM_U8(partitionTableHeader[48],
                                                               partitionTableHeader[49],
                                                               partitionTableHeader[50],
@@ -1068,6 +1076,7 @@ static int partRead(RTFILE File, PHOSTPARTITIONS pPart)
 
 static RTEXITCODE CmdListPartitions(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     Utf8Str rawdisk;
 
     /* let's have a closer look at the arguments */
@@ -1142,6 +1151,7 @@ static PVBOXHDDRAWPARTDESC appendPartDesc(uint32_t *pcPartDescs, PVBOXHDDRAWPART
 
 static RTEXITCODE CmdCreateRawVMDK(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     HRESULT rc = S_OK;
     Utf8Str filename;
     const char *pszMBRFilename = NULL;
@@ -1861,6 +1871,7 @@ out:
 
 static RTEXITCODE CmdRenameVMDK(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     Utf8Str src;
     Utf8Str dst;
     /* Parse the arguments. */
@@ -1927,6 +1938,7 @@ static RTEXITCODE CmdRenameVMDK(int argc, char **argv, ComPtr<IVirtualBox> aVirt
 
 static RTEXITCODE CmdConvertToRaw(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     Utf8Str srcformat;
     Utf8Str src;
     Utf8Str dst;
@@ -1978,7 +1990,7 @@ static RTEXITCODE CmdConvertToRaw(int argc, char **argv, ComPtr<IVirtualBox> aVi
                              NULL, sizeof(VDINTERFACEERROR), &pVDIfs);
     AssertRC(vrc);
 
-    /** @todo: Support convert to raw for floppy and DVD images too. */
+    /** @todo Support convert to raw for floppy and DVD images too. */
     vrc = VDCreate(pVDIfs, VDTYPE_HDD, &pDisk);
     if (RT_FAILURE(vrc))
         return RTMsgErrorExit(RTEXITCODE_FAILURE, "Cannot create the virtual disk container: %Rrc", vrc);
@@ -2082,6 +2094,7 @@ static RTEXITCODE CmdConvertToRaw(int argc, char **argv, ComPtr<IVirtualBox> aVi
 
 static RTEXITCODE CmdConvertHardDisk(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     Utf8Str srcformat;
     Utf8Str dstformat;
     Utf8Str src;
@@ -2213,11 +2226,11 @@ static RTEXITCODE CmdConvertHardDisk(int argc, char **argv, ComPtr<IVirtualBox>
  */
 static RTEXITCODE CmdRepairHardDisk(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
     Utf8Str image;
     Utf8Str format;
     int vrc;
     bool fDryRun = false;
-    PVBOXHDD pDisk = NULL;
 
     /* Parse the arguments. */
     for (int i = 0; i < argc; i++)
@@ -2432,6 +2445,8 @@ static RTEXITCODE CmdDebugLog(int argc, char **argv, ComPtr<IVirtualBox> aVirtua
  */
 static RTEXITCODE CmdGeneratePasswordHash(int argc, char **argv, ComPtr<IVirtualBox> aVirtualBox, ComPtr<ISession> aSession)
 {
+    RT_NOREF(aVirtualBox, aSession);
+
     /* one parameter, the password to hash */
     if (argc != 1)
         return errorSyntax(USAGE_PASSWORDHASH, "password to hash required");
