@@ -502,6 +502,7 @@ RTEXITCODE handleModifyMedium(HandlerArg *a)
     bool fModifyProperties = false;
     bool fModifyCompact = false;
     bool fModifyResize = false;
+    bool fModifyResizeMB = false;
     bool fModifyLocation = false;
     uint64_t cbResize = 0;
     const char *pszFilenameOrUuid = NULL;
@@ -588,6 +589,7 @@ RTEXITCODE handleModifyMedium(HandlerArg *a)
             case 'r':   // --resize
                 cbResize = ValueUnion.u64 * _1M;
                 fModifyResize = true;
+                fModifyResizeMB = true; // do sanity check!
                 break;
 
             case 'R':   // --resizebyte
@@ -657,6 +659,29 @@ RTEXITCODE handleModifyMedium(HandlerArg *a)
         return RTEXITCODE_FAILURE;
     }
 
+    if (   fModifyResize
+        && fModifyResizeMB)
+    {
+        // Sanity check
+        //
+        // In general users should know what they do but in this case users have no
+        // alternative to VBoxManage. If happens that one wants to resize the disk
+        // and uses --resize and does not consider that this parameter expects the
+        // new medium size in MB not Byte. If the operation is started and then
+        // aborted by the user, the result is most likely a medium which doesn't
+        // work anymore.
+        MediumState_T state;
+        pMedium->RefreshState(&state);
+        LONG64 logicalSize;
+        pMedium->COMGETTER(LogicalSize)(&logicalSize);
+        if (cbResize > (uint64_t)logicalSize * 1000)
+        {
+            RTMsgError("Error: Attempt to resize the medium from %RU64.%RU64 MB to %RU64.%RU64 MB. Use --resizebyte if this is intended!\n",
+                    logicalSize / _1M, (logicalSize % _1M) / (_1M / 10), cbResize / _1M, (cbResize % _1M) / (_1M / 10));
+            return RTEXITCODE_FAILURE;
+        }
+    }
+
     if (fModifyMediumType)
     {
         MediumType_T enmCurrMediumType;
@@ -1138,7 +1163,6 @@ HRESULT showMediumInfo(const ComPtr<IVirtualBox> &pVirtualBox,
         /* check for accessibility */
         MediumState_T enmState;
         CHECK_ERROR_BREAK(pMedium, RefreshState(&enmState));
-        pMedium->RefreshState(&enmState);
         const char *pszState = "unknown";
         switch (enmState)
         {
