@@ -30,7 +30,6 @@
 # include "UIWizardNewVM.h"
 # include "UIMessageCenter.h"
 # include "UINameAndSystemEditor.h"
-# include "UIFilePathSelector.h"
 # include "QIRichTextLabel.h"
 
 /* COM includes: */
@@ -116,12 +115,12 @@ static const osTypePattern gs_OSTypePattern[] =
     { QRegExp("((Mac)|(Tig)|(Leop)|(Yose)|(os[ ]*x)).*32",                                      Qt::CaseInsensitive), "MacOS" },
 
     /* Code names for Linux distributions: */
-    { QRegExp("((bianca)|(cassandra)|(celena)|(daryna)|(elyssa)|(felicia)|(gloria)|(helena)|(isadora)|(julia)|(katya)|(lisa)|(maya)|(nadia)|(olivia)|(petra)|(qiana)|(rebecca)|(rafaela)|(rosa)).*64",    Qt::CaseInsensitive), "Ubuntu_64" },
-    { QRegExp("((bianca)|(cassandra)|(celena)|(daryna)|(elyssa)|(felicia)|(gloria)|(helena)|(isadora)|(julia)|(katya)|(lisa)|(maya)|(nadia)|(olivia)|(petra)|(qiana)|(rebecca)|(rafaela)|(rosa)).*32",    Qt::CaseInsensitive), "Ubuntu" },
-    { QRegExp("((edgy)|(feisty)|(gutsy)|(hardy)|(intrepid)|(jaunty)|(karmic)|(lucid)|(maverick)|(natty)|(oneiric)|(precise)|(quantal)|(raring)|(saucy)|(trusty)|(utopic)|(vivid)|(wily)|(xenial)).*64",    Qt::CaseInsensitive), "Ubuntu_64" },
-    { QRegExp("((edgy)|(feisty)|(gutsy)|(hardy)|(intrepid)|(jaunty)|(karmic)|(lucid)|(maverick)|(natty)|(oneiric)|(precise)|(quantal)|(raring)|(saucy)|(trusty)|(utopic)|(vivid)|(wily)|(xenial)).*32",    Qt::CaseInsensitive), "Ubuntu" },
-    { QRegExp("((sarge)|(etch)|(lenny)|(squeeze)|(wheezy)|(jessie)|(sid)).*64",                                                                          Qt::CaseInsensitive), "Debian_64" },
-    { QRegExp("((sarge)|(etch)|(lenny)|(squeeze)|(wheezy)|(jessie)|(sid)).*32",                                                                          Qt::CaseInsensitive), "Debian" },
+    { QRegExp("((bianca)|(cassandra)|(celena)|(daryna)|(elyssa)|(felicia)|(gloria)|(helena)|(isadora)|(julia)|(katya)|(lisa)|(maya)|(nadia)|(olivia)|(petra)|(qiana)|(rebecca)|(rafaela)|(rosa)).*64", Qt::CaseInsensitive), "Ubuntu_64" },
+    { QRegExp("((bianca)|(cassandra)|(celena)|(daryna)|(elyssa)|(felicia)|(gloria)|(helena)|(isadora)|(julia)|(katya)|(lisa)|(maya)|(nadia)|(olivia)|(petra)|(qiana)|(rebecca)|(rafaela)|(rosa)).*32", Qt::CaseInsensitive), "Ubuntu" },
+    { QRegExp("((edgy)|(feisty)|(gutsy)|(hardy)|(intrepid)|(jaunty)|(karmic)|(lucid)|(maverick)|(natty)|(oneiric)|(precise)|(quantal)|(raring)|(saucy)|(trusty)|(utopic)|(vivid)|(wily)|(xenial)|(yakkety)|(zesty)).*64", Qt::CaseInsensitive), "Ubuntu_64" },
+    { QRegExp("((edgy)|(feisty)|(gutsy)|(hardy)|(intrepid)|(jaunty)|(karmic)|(lucid)|(maverick)|(natty)|(oneiric)|(precise)|(quantal)|(raring)|(saucy)|(trusty)|(utopic)|(vivid)|(wily)|(xenial)|(yakkety)|(zesty)).*32", Qt::CaseInsensitive), "Ubuntu" },
+    { QRegExp("((sarge)|(etch)|(lenny)|(squeeze)|(wheezy)|(jessie)|(stretch)|(buster)|(sid)).*64", Qt::CaseInsensitive), "Debian_64" },
+    { QRegExp("((sarge)|(etch)|(lenny)|(squeeze)|(wheezy)|(jessie)|(stretch)|(buster)|(sid)).*32", Qt::CaseInsensitive), "Debian" },
     { QRegExp("((moonshine)|(werewolf)|(sulphur)|(cambridge)|(leonidas)|(constantine)|(goddard)|(laughlin)|(lovelock)|(verne)|(beefy)|(spherical)).*64", Qt::CaseInsensitive), "Fedora_64" },
     { QRegExp("((moonshine)|(werewolf)|(sulphur)|(cambridge)|(leonidas)|(constantine)|(goddard)|(laughlin)|(lovelock)|(verne)|(beefy)|(spherical)).*32", Qt::CaseInsensitive), "Fedora" },
 
@@ -204,32 +203,6 @@ void UIWizardNewVMPage1::onOsTypeChanged()
     m_pNameAndSystemEditor->disconnect(SIGNAL(sigNameChanged(const QString &)), thisImp(), SLOT(sltNameChanged(const QString &)));
 }
 
-void UIWizardNewVMPage1::adjustToolTip(const QString &strNewName /* = QString() */)
-{
-    /* Compose tool-tip: */
-    QString strToolTip;
-    /* If name is empty: */
-    if (strNewName.isEmpty())
-    {
-        /* We are just reseting the tool-tip to default: */
-        strToolTip = UIWizardNewVM::tr("<p><nobr>Holds the name or full path to the virtual "
-                                       "machine folder you are about to create.</nobr></p>");
-    }
-    /* If name is NOT empty: */
-    else
-    {
-        /* Compose the machine file-path, acquire the machine folder from it: */
-        const QString strMachineFilePath = composeMachineFilePath(strNewName);
-        const QString strMachineFolder = QDir::toNativeSeparators(QFileInfo(strMachineFilePath).absolutePath());
-        /* And compose the location-editor tool-tip accordingly: */
-        strToolTip = UIWizardNewVM::tr("<p><nobr>You are about to create the virtual machine in the "
-                                       "following folder:</nobr><br><nobr><b>%1</b></nobr></p>")
-                                       .arg(strMachineFolder);
-    }
-    /* Assign tool-tip: */
-    m_pNameAndSystemEditor->locationEditor()->setToolTip(strToolTip);
-}
-
 bool UIWizardNewVMPage1::machineFolderCreated()
 {
     return !m_strMachineFolder.isEmpty();
@@ -244,10 +217,19 @@ bool UIWizardNewVMPage1::createMachineFolder()
         return false;
     }
 
-    /* Compose machine file-path, parse it to folder and base-name: */
-    const QString strMachineFilePath = composeMachineFilePath(m_pNameAndSystemEditor->name());
-    const QString strMachineFolder = QDir::toNativeSeparators(QFileInfo(strMachineFilePath).absolutePath());
-    const QString strMachineBaseName = QFileInfo(strMachineFilePath).completeBaseName();
+    /* Get VBox: */
+    CVirtualBox vbox = vboxGlobal().virtualBox();
+    /* Get default machine folder: */
+    const QString strDefaultMachineFolder = vbox.GetSystemProperties().GetDefaultMachineFolder();
+    /* Compose machine filename: */
+    const QString strMachineFilePath = vbox.ComposeMachineFilename(m_pNameAndSystemEditor->name(),
+                                                                   m_strGroup,
+                                                                   QString(),
+                                                                   strDefaultMachineFolder);
+    /* Compose machine folder/basename: */
+    const QFileInfo fileInfo(strMachineFilePath);
+    const QString strMachineFolder = fileInfo.absolutePath();
+    const QString strMachineBaseName = fileInfo.completeBaseName();
 
     /* Make sure that folder doesn't exists: */
     if (QDir(strMachineFolder).exists())
@@ -267,7 +249,6 @@ bool UIWizardNewVMPage1::createMachineFolder()
     /* Initialize fields: */
     m_strMachineFolder = strMachineFolder;
     m_strMachineBaseName = strMachineBaseName;
-    m_strMachineFilePath = strMachineFilePath;
     return true;
 }
 
@@ -285,23 +266,6 @@ bool UIWizardNewVMPage1::cleanupMachineFolder()
     return fMachineFolderRemoved;
 }
 
-QString UIWizardNewVMPage1::composeMachineFilePath(const QString &strUserMachineLocation)
-{
-    /* Get VBox: */
-    CVirtualBox vbox = vboxGlobal().virtualBox();
-    /* Get default machine folder: */
-    const QString strDefaultMachineFolder = vbox.GetSystemProperties().GetDefaultMachineFolder();
-    /* Fetch user's machine location: */
-    const QString strUserMachineFolder = QFileInfo(strUserMachineLocation).absolutePath();
-    const QString strUserMachineBaseName = QFileInfo(strUserMachineLocation).fileName();
-    const bool fUseDefaultPath = strUserMachineLocation == strUserMachineBaseName;
-    /* Compose machine filename: */
-    return vbox.ComposeMachineFilename(strUserMachineBaseName,
-                                       fUseDefaultPath ? m_strGroup : QString() /* no group in that case */,
-                                       QString(),
-                                       fUseDefaultPath ? strDefaultMachineFolder : strUserMachineFolder);
-}
-
 UIWizardNewVMPageBasic1::UIWizardNewVMPageBasic1(const QString &strGroup)
     : UIWizardNewVMPage1(strGroup)
 {
@@ -309,7 +273,7 @@ UIWizardNewVMPageBasic1::UIWizardNewVMPageBasic1(const QString &strGroup)
     QVBoxLayout *pMainLayout = new QVBoxLayout(this);
     {
         m_pLabel = new QIRichTextLabel(this);
-        m_pNameAndSystemEditor = new UINameAndSystemEditor(this, true);
+        m_pNameAndSystemEditor = new UINameAndSystemEditor(this);
         pMainLayout->addWidget(m_pLabel);
         pMainLayout->addWidget(m_pNameAndSystemEditor);
         pMainLayout->addStretch();
@@ -317,7 +281,6 @@ UIWizardNewVMPageBasic1::UIWizardNewVMPageBasic1(const QString &strGroup)
 
     /* Setup connections: */
     connect(m_pNameAndSystemEditor, SIGNAL(sigNameChanged(const QString &)), this, SLOT(sltNameChanged(const QString &)));
-    connect(m_pNameAndSystemEditor, SIGNAL(sigNameChanged(const QString &)), this, SLOT(sltAdjustToolTip(const QString &)));
     connect(m_pNameAndSystemEditor, SIGNAL(sigOsTypeChanged()), this, SLOT(sltOsTypeChanged()));
 
     /* Register fields: */
@@ -325,10 +288,6 @@ UIWizardNewVMPageBasic1::UIWizardNewVMPageBasic1(const QString &strGroup)
     registerField("type", m_pNameAndSystemEditor, "type", SIGNAL(sigOsTypeChanged()));
     registerField("machineFolder", this, "machineFolder");
     registerField("machineBaseName", this, "machineBaseName");
-    registerField("machineFilePath", this, "machineFilePath");
-
-    /* Initialize tool-tip: */
-    adjustToolTip();
 }
 
 void UIWizardNewVMPageBasic1::sltNameChanged(const QString &strNewName)
@@ -337,12 +296,6 @@ void UIWizardNewVMPageBasic1::sltNameChanged(const QString &strNewName)
     onNameChanged(strNewName);
 }
 
-void UIWizardNewVMPageBasic1::sltAdjustToolTip(const QString &strNewName)
-{
-    /* Call to base-class: */
-    adjustToolTip(strNewName);
-}
-
 void UIWizardNewVMPageBasic1::sltOsTypeChanged()
 {
     /* Call to base-class: */
