@@ -6,7 +6,7 @@ VirtualBox Python API Glue.
 
 __copyright__ = \
     """
-    Copyright (C) 2009-2015 Oracle Corporation
+    Copyright (C) 2009-2016 Oracle Corporation
 
     This file is part of VirtualBox Open Source Edition (OSE), as
     available from http://www.virtualbox.org. This file is free software;
@@ -25,7 +25,7 @@ __copyright__ = \
     You may elect to license modified versions of this file under the
     terms and conditions of either the GPL or the CDDL or both.
     """
-__version__ = "$Revision: 106598 $"
+__version__ = "$Revision: 109501 $"
 
 
 # Note! To set Python bitness on OSX use 'export VERSIONER_PYTHON_PREFER_32_BIT=yes'
@@ -40,64 +40,6 @@ import traceback
 if sys.version_info >= (3, 0):
     xrange = range
     long = int
-    import builtins
-    print_ = getattr(builtins, 'print', None)
-elif sys.version_info >= (2, 6):
-    import __builtin__
-    print_ = getattr(__builtin__, 'print', None)
-else:
-    def print_(*args, **kwargs):
-        """The new-style print function for Python 2.4 and 2.5."""
-        fp = kwargs.pop("file", sys.stdout)
-        if fp is None:
-            return
-
-        def write(data):
-            if not isinstance(data, basestring):
-                data = str(data)
-            # If the file has an encoding, encode unicode with it.
-            if isinstance(fp, file) and isinstance(data, unicode) and fp.encoding is not None:
-                errors = getattr(fp, "errors", None)
-                if errors is None:
-                    errors = "strict"
-                data = data.encode(fp.encoding, errors)
-            fp.write(data)
-
-        want_unicode = False
-        sep = kwargs.pop("sep", None)
-        if sep is not None:
-            if isinstance(sep, unicode):
-                want_unicode = True
-            elif not isinstance(sep, str):
-                raise TypeError("sep must be None or a string")
-        end = kwargs.pop("end", None)
-        if end is not None:
-            if isinstance(end, unicode):
-                want_unicode = True
-            elif not isinstance(end, str):
-                raise TypeError("end must be None or a string")
-        if kwargs:
-            raise TypeError("invalid keyword arguments to print()")
-        if not want_unicode:
-            for arg in args:
-                if isinstance(arg, unicode):
-                    want_unicode = True
-                    break
-        if want_unicode:
-            newline = unicode("\n")
-            space = unicode(" ")
-        else:
-            newline = "\n"
-            space = " "
-        if sep is None:
-            sep = space
-        if end is None:
-            end = newline
-        for i, arg in enumerate(args):
-            if i:
-                write(sep)
-            write(arg)
-        write(end)
 
 #
 # Globals, environment and sys.path changes.
@@ -233,7 +175,7 @@ def _CustomGetAttr(self, sAttr):
 
     # Try case-insensitivity workaround for class attributes (COM methods).
     sAttrLower = sAttr.lower()
-    for k in self.__class__.__dict__.keys():
+    for k in list(self.__class__.__dict__.keys()):
         if k.lower() == sAttrLower:
             setattr(self.__class__, sAttr, self.__class__.__dict__[k])
             return getattr(self, k)
@@ -521,6 +463,7 @@ class PlatformMSCOM(PlatformBase):
         self.flushGenPyCache(win32com.client.gencache)
         win32com.client.gencache.EnsureDispatch('VirtualBox.Session')
         win32com.client.gencache.EnsureDispatch('VirtualBox.VirtualBox')
+        win32com.client.gencache.EnsureDispatch('VirtualBox.VirtualBoxClient')
 
         self.oIntCv = threading.Condition()
         self.fInterrupted = False
@@ -564,7 +507,8 @@ class PlatformMSCOM(PlatformBase):
     def getVirtualBox(self):
         import win32com
         from win32com.client import Dispatch
-        return win32com.client.Dispatch("VirtualBox.VirtualBox")
+        client = win32com.client.Dispatch("VirtualBox.VirtualBoxClient")
+        return client.virtualBox
 
     def getType(self):
         return 'MSCOM'
@@ -795,7 +739,8 @@ class PlatformXPCOM(PlatformBase):
 
     def getVirtualBox(self):
         import xpcom.components
-        return xpcom.components.classes["@virtualbox.org/VirtualBox;1"].createInstance()
+        client = xpcom.components.classes["@virtualbox.org/VirtualBoxClient;1"].createInstance()
+        return client.virtualBox
 
     def getType(self):
         return 'XPCOM'
@@ -1050,12 +995,12 @@ class VirtualBoxManager(object):
         try:
             self.vbox = self.platform.getVirtualBox()
         except NameError:
-            print_("Installation problem: check that appropriate libs in place")
+            print("Installation problem: check that appropriate libs in place")
             traceback.print_exc()
             raise
         except Exception:
             _, e, _ = sys.exc_info()
-            print_("init exception: ", e)
+            print("init exception: ", e)
             traceback.print_exc()
             if self.remote:
                 self.vbox = None
@@ -1131,10 +1076,10 @@ class VirtualBoxManager(object):
         For unitializing the manager.
         Do not access it after calling this method.
         """
-        if hasattr(self, "vbox"):
+        if hasattr(self, "vbox") and self.vbox is not None:
             del self.vbox
             self.vbox = None
-        if hasattr(self, "platform"):
+        if hasattr(self, "platform") and self.platform is not None:
             self.platform.deinit()
             self.platform = None
         return True
@@ -1150,10 +1095,10 @@ class VirtualBoxManager(object):
         """
         oSession = self.getSessionObject(self.vbox);
         if fPermitSharing:
-            type_ = self.constants.LockType_Shared
+            eType = self.constants.LockType_Shared
         else:
-            type_ = self.constants.LockType_Write
-        oIMachine.lockMachine(oSession, type_)
+            eType = self.constants.LockType_Write
+        oIMachine.lockMachine(oSession, eType)
         return oSession
 
     def closeMachineSession(self, oSession):
